@@ -12,11 +12,15 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA. */
+
+/* Modified from the original to add stdlib.h and string.h */
 
 #ifndef GOT_GETDATE_H
 #define GOT_GETDATE_H
 
+#include <stdlib.h>
+#include <string.h>
 #include <time.h>
 
 time_t get_date (const char *p, const time_t *now);
