@@ -21,8 +21,6 @@
 #include <config.h>
 #include "test.h"
 
-#if defined(FEAT_NTP) || defined(FEAT_CMDMON)
-
 #include <clientlog.c>
 
 static uint64_t
@@ -321,10 +319,3 @@ test_unit(void)
   LCL_Finalise();
   CNF_Finalise();
 }
-#else
-void
-test_unit(void)
-{
-  TEST_REQUIRE(0);
-}
-#endif
